contexttools.get_tempo_mark_attached_to_component
=================================================

.. autofunction:: abjad.tools.contexttools.get_tempo_mark_attached_to_component.get_tempo_mark_attached_to_component
